@@ -6,28 +6,7 @@ from pickle import TRUE
 from .routestructure.routestructure import routes_list
 from .routestructure.template import Imports, ImportsListroutes, ImportsController, ImportsSchemas
 
-parser = argparse.ArgumentParser(description='FastApi Multitenant.')
 
-parser.add_argument("--route", help="Crete new route.")
-parser.add_argument("--r", help="Crete new route.")
-parser.add_argument("--remove-route", help="Remove route.")
-parser.add_argument("--rm-r", help="Remove route.")
-parser.add_argument("--migrate", help="Migarte.", nargs='?', const=1, type=int)
-parser.add_argument("--makemigration", help="Migarte.")
-
-args = parser.parse_args()
-
-def options_command(argument):
-    for arg in vars(argument):
-        if getattr(args, arg) is not None:
-            if arg == "route" or arg == "r":
-                create_route(getattr(args, arg))
-            if arg == "remove_route" or arg == "rm_r":
-                remove_route(getattr(args, arg))     
-            if arg == "makemigration":
-                makemigration(getattr(args, arg))
-            if arg == "migrate":
-                migrate()
 
 def migrate():
     subprocess.run(['alembic', 'upgrade', 'head'])
@@ -166,8 +145,29 @@ def verify_remove_route(route):
     print("Error: Route "+route+" does'n exists.")
        
     routes_list.remove
-    
-def main(args=None):
+
+parser = argparse.ArgumentParser(description='FastApi Multitenant.')
+parser.add_argument("--route", help="Crete new route.")
+parser.add_argument("--r", help="Crete new route.")
+parser.add_argument("--remove-route", help="Remove route.")
+parser.add_argument("--rm-r", help="Remove route.")
+parser.add_argument("--migrate", help="Migarte.", nargs='?', const=1, type=int)
+parser.add_argument("--makemigration", help="Migarte.")
+args = parser.parse_args()
+
+def options_command(argument):
+    for arg in vars(argument):
+        if getattr(args, arg) is not None:
+            if arg == "route":
+                create_route(getattr(args, arg))
+            if arg == "remove_route":
+                remove_route(getattr(args, arg))     
+            if arg == "makemigration":
+                makemigration(getattr(args, arg))
+            if arg == "migrate":
+                migrate()
+   
+def main(args):
     options_command(args)
 
 if __name__ == "__main__":
